<?php

return [
    'Names' => [
        'af' => 'ଆଫ୍ରିକୀୟ',
        'af_NA' => 'ଆଫ୍ରିକୀୟ (ନାମିବିଆ)',
        'af_ZA' => 'ଆଫ୍ରିକୀୟ (ଦକ୍ଷିଣ ଆଫ୍ରିକା)',
        'ak' => 'ଅକନ୍',
        'ak_GH' => 'ଅକନ୍ (ଘାନା)',
        'am' => 'ଆମହାରକି',
        'am_ET' => 'ଆମହାରକି (ଇଥିଓପିଆ)',
        'ar' => 'ଆରବିକ୍',
        'ar_001' => 'ଆରବିକ୍ (ବିଶ୍ୱ)',
        'ar_AE' => 'ଆରବିକ୍ (ସଂଯୁକ୍ତ ଆରବ ଏମିରେଟସ୍)',
        'ar_BH' => 'ଆରବିକ୍ (ବାହାରିନ୍)',
        'ar_DJ' => 'ଆରବିକ୍ (ଜିବୋଟି)',
        'ar_DZ' => 'ଆରବିକ୍ (ଆଲଜେରିଆ)',
        'ar_EG' => 'ଆରବିକ୍ (ଇଜିପ୍ଟ)',
        'ar_EH' => 'ଆରବିକ୍ (ପଶ୍ଚିମ ସାହାରା)',
        'ar_ER' => 'ଆରବିକ୍ (ଇରିଟ୍ରିୟା)',
        'ar_IL' => 'ଆରବିକ୍ (ଇସ୍ରାଏଲ୍)',
        'ar_IQ' => 'ଆରବିକ୍ (ଇରାକ୍)',
        'ar_JO' => 'ଆରବିକ୍ (ଜୋର୍ଡାନ୍)',
        'ar_KM' => 'ଆରବିକ୍ (କୋମୋରସ୍)',
        'ar_KW' => 'ଆରବିକ୍ (କୁଏତ୍)',
        'ar_LB' => 'ଆରବିକ୍ (ଲେବାନନ୍)',
        'ar_LY' => 'ଆରବିକ୍ (ଲିବ୍ୟା)',
        'ar_MA' => 'ଆରବିକ୍ (ମୋରୋକ୍କୋ)',
        'ar_MR' => 'ଆରବିକ୍ (ମୌରିଟାନିଆ)',
        'ar_OM' => 'ଆରବିକ୍ (ଓମାନ୍)',
        'ar_PS' => 'ଆରବିକ୍ (ପାଲେଷ୍ଟେନିୟ ଭୂଭାଗ)',
        'ar_QA' => 'ଆରବିକ୍ (କତାର୍)',
        'ar_SA' => 'ଆରବିକ୍ (ସାଉଦି ଆରବିଆ)',
        'ar_SD' => 'ଆରବିକ୍ (ସୁଦାନ)',
        'ar_SO' => 'ଆରବିକ୍ (ସୋମାଲିଆ)',
        'ar_SS' => 'ଆରବିକ୍ (ଦକ୍ଷିଣ ସୁଦାନ)',
        'ar_SY' => 'ଆରବିକ୍ (ସିରିଆ)',
        'ar_TD' => 'ଆରବିକ୍ (ଚାଦ୍)',
        'ar_TN' => 'ଆରବିକ୍ (ଟ୍ୟୁନିସିଆ)',
        'ar_YE' => 'ଆରବିକ୍ (ୟେମେନ୍)',
        'as' => 'ଆସାମୀୟ',
        'as_IN' => 'ଆସାମୀୟ (ଭାରତ)',
        'az' => 'ଆଜେରବାଇଜାନି',
        'az_AZ' => 'ଆଜେରବାଇଜାନି (ଆଜେରବାଇଜାନ୍)',
        'az_Cyrl' => 'ଆଜେରବାଇଜାନି (ସିରିଲିକ୍)',
        'az_Cyrl_AZ' => 'ଆଜେରବାଇଜାନି (ସିରିଲିକ୍, ଆଜେରବାଇଜାନ୍)',
        'az_Latn' => 'ଆଜେରବାଇଜାନି (ଲାଟିନ୍)',
        'az_Latn_AZ' => 'ଆଜେରବାଇଜାନି (ଲାଟିନ୍, ଆଜେରବାଇଜାନ୍)',
        'be' => 'ବେଲାରୁଷିଆନ୍',
        'be_BY' => 'ବେଲାରୁଷିଆନ୍ (ବେଲାରୁଷ୍)',
        'bg' => 'ବୁଲଗେରିଆନ୍',
        'bg_BG' => 'ବୁଲଗେରିଆନ୍ (ବୁଲଗେରିଆ)',
        'bm' => 'ବାମ୍ବାରା',
        'bm_ML' => 'ବାମ୍ବାରା (ମାଲି)',
        'bn' => 'ବଙ୍ଗଳା',
        'bn_BD' => 'ବଙ୍ଗଳା (ବାଂଲାଦେଶ)',
        'bn_IN' => 'ବଙ୍ଗଳା (ଭାରତ)',
        'bo' => 'ତିବ୍ବତୀୟ',
        'bo_CN' => 'ତିବ୍ବତୀୟ (ଚିନ୍)',
        'bo_IN' => 'ତିବ୍ବତୀୟ (ଭାରତ)',
        'br' => 'ବ୍ରେଟନ୍',
        'br_FR' => 'ବ୍ରେଟନ୍ (ଫ୍ରାନ୍ସ)',
        'bs' => 'ବୋସନିଆନ୍',
        'bs_BA' => 'ବୋସନିଆନ୍ (ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'bs_Cyrl' => 'ବୋସନିଆନ୍ (ସିରିଲିକ୍)',
        'bs_Cyrl_BA' => 'ବୋସନିଆନ୍ (ସିରିଲିକ୍, ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'bs_Latn' => 'ବୋସନିଆନ୍ (ଲାଟିନ୍)',
        'bs_Latn_BA' => 'ବୋସନିଆନ୍ (ଲାଟିନ୍, ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'ca' => 'କାଟାଲାନ୍',
        'ca_AD' => 'କାଟାଲାନ୍ (ଆଣ୍ଡୋରା)',
        'ca_ES' => 'କାଟାଲାନ୍ (ସ୍ପେନ୍)',
        'ca_FR' => 'କାଟାଲାନ୍ (ଫ୍ରାନ୍ସ)',
        'ca_IT' => 'କାଟାଲାନ୍ (ଇଟାଲୀ)',
        'ce' => 'ଚେଚନ୍',
        'ce_RU' => 'ଚେଚନ୍ (ରୁଷିଆ)',
        'cs' => 'ଚେକ୍',
        'cs_CZ' => 'ଚେକ୍ (ଚେଚିଆ)',
        'cv' => 'ଚୁଭାଶ୍',
        'cv_RU' => 'ଚୁଭାଶ୍ (ରୁଷିଆ)',
        'cy' => 'ୱେଲ୍ସ',
        'cy_GB' => 'ୱେଲ୍ସ (ଯୁକ୍ତରାଜ୍ୟ)',
        'da' => 'ଡାନ୍ନିସ୍',
        'da_DK' => 'ଡାନ୍ନିସ୍ (ଡେନମାର୍କ)',
        'da_GL' => 'ଡାନ୍ନିସ୍ (ଗ୍ରୀନଲ୍ୟାଣ୍ଡ)',
        'de' => 'ଜର୍ମାନ',
        'de_AT' => 'ଜର୍ମାନ (ଅଷ୍ଟ୍ରିଆ)',
        'de_BE' => 'ଜର୍ମାନ (ବେଲଜିୟମ୍)',
        'de_CH' => 'ଜର୍ମାନ (ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ)',
        'de_DE' => 'ଜର୍ମାନ (ଜର୍ମାନୀ)',
        'de_IT' => 'ଜର୍ମାନ (ଇଟାଲୀ)',
        'de_LI' => 'ଜର୍ମାନ (ଲିଚେଟନଷ୍ଟେଇନ୍)',
        'de_LU' => 'ଜର୍ମାନ (ଲକ୍ସେମବର୍ଗ)',
        'dz' => 'ଦଡଜୋଙ୍ଗଖା',
        'dz_BT' => 'ଦଡଜୋଙ୍ଗଖା (ଭୁଟାନ)',
        'ee' => 'ଇୱେ',
        'ee_GH' => 'ଇୱେ (ଘାନା)',
        'ee_TG' => 'ଇୱେ (ଟୋଗୋ)',
        'el' => 'ଗ୍ରୀକ୍',
        'el_CY' => 'ଗ୍ରୀକ୍ (ସାଇପ୍ରସ୍)',
        'el_GR' => 'ଗ୍ରୀକ୍ (ଗ୍ରୀସ୍)',
        'en' => 'ଇଂରାଜୀ',
        'en_001' => 'ଇଂରାଜୀ (ବିଶ୍ୱ)',
        'en_150' => 'ଇଂରାଜୀ (ୟୁରୋପ୍)',
        'en_AE' => 'ଇଂରାଜୀ (ସଂଯୁକ୍ତ ଆରବ ଏମିରେଟସ୍)',
        'en_AG' => 'ଇଂରାଜୀ (ଆଣ୍ଟିଗୁଆ ଏବଂ ବାରବୁଦା)',
        'en_AI' => 'ଇଂରାଜୀ (ଆଙ୍ଗୁଇଲ୍ଲା)',
        'en_AS' => 'ଇଂରାଜୀ (ଆମେରିକାନ୍ ସାମୋଆ)',
        'en_AT' => 'ଇଂରାଜୀ (ଅଷ୍ଟ୍ରିଆ)',
        'en_AU' => 'ଇଂରାଜୀ (ଅଷ୍ଟ୍ରେଲିଆ)',
        'en_BB' => 'ଇଂରାଜୀ (ବାରବାଡୋସ୍)',
        'en_BE' => 'ଇଂରାଜୀ (ବେଲଜିୟମ୍)',
        'en_BI' => 'ଇଂରାଜୀ (ବୁରୁଣ୍ଡି)',
        'en_BM' => 'ଇଂରାଜୀ (ବର୍ମୁଡା)',
        'en_BS' => 'ଇଂରାଜୀ (ବାହାମାସ୍)',
        'en_BW' => 'ଇଂରାଜୀ (ବୋଟସ୍ୱାନା)',
        'en_BZ' => 'ଇଂରାଜୀ (ବେଲିଜ୍)',
        'en_CA' => 'ଇଂରାଜୀ (କାନାଡା)',
        'en_CC' => 'ଇଂରାଜୀ (କୋକୋସ୍ [କୀଲିଂ] ଦ୍ଵୀପପୁଞ୍ଜ)',
        'en_CH' => 'ଇଂରାଜୀ (ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ)',
        'en_CK' => 'ଇଂରାଜୀ (କୁକ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_CM' => 'ଇଂରାଜୀ (କାମେରୁନ୍)',
        'en_CX' => 'ଇଂରାଜୀ (ଖ୍ରୀଷ୍ଟମାସ ଦ୍ୱୀପ)',
        'en_CY' => 'ଇଂରାଜୀ (ସାଇପ୍ରସ୍)',
        'en_DE' => 'ଇଂରାଜୀ (ଜର୍ମାନୀ)',
        'en_DK' => 'ଇଂରାଜୀ (ଡେନମାର୍କ)',
        'en_DM' => 'ଇଂରାଜୀ (ଡୋମିନିକା)',
        'en_ER' => 'ଇଂରାଜୀ (ଇରିଟ୍ରିୟା)',
        'en_FI' => 'ଇଂରାଜୀ (ଫିନଲ୍ୟାଣ୍ଡ)',
        'en_FJ' => 'ଇଂରାଜୀ (ଫିଜି)',
        'en_FK' => 'ଇଂରାଜୀ (ଫକ୍‌ଲ୍ୟାଣ୍ଡ ଦ୍ଵୀପପୁଞ୍ଜ)',
        'en_FM' => 'ଇଂରାଜୀ (ମାଇକ୍ରୋନେସିଆ)',
        'en_GB' => 'ଇଂରାଜୀ (ଯୁକ୍ତରାଜ୍ୟ)',
        'en_GD' => 'ଇଂରାଜୀ (ଗ୍ରେନାଡା)',
        'en_GG' => 'ଇଂରାଜୀ (ଗୁଏରନେସି)',
        'en_GH' => 'ଇଂରାଜୀ (ଘାନା)',
        'en_GI' => 'ଇଂରାଜୀ (ଜିବ୍ରାଲ୍ଟର୍)',
        'en_GM' => 'ଇଂରାଜୀ (ଗାମ୍ବିଆ)',
        'en_GU' => 'ଇଂରାଜୀ (ଗୁଆମ୍)',
        'en_GY' => 'ଇଂରାଜୀ (ଗୁଇନା)',
        'en_HK' => 'ଇଂରାଜୀ (ହଂ କଂ ଏସଏଆର୍‌ ଚାଇନା)',
        'en_IE' => 'ଇଂରାଜୀ (ଆୟରଲ୍ୟାଣ୍ଡ)',
        'en_IL' => 'ଇଂରାଜୀ (ଇସ୍ରାଏଲ୍)',
        'en_IM' => 'ଇଂରାଜୀ (ଆଇଲ୍‌ ଅଫ୍‌ ମ୍ୟାନ୍‌)',
        'en_IN' => 'ଇଂରାଜୀ (ଭାରତ)',
        'en_IO' => 'ଇଂରାଜୀ (ବ୍ରିଟିଶ୍‌ ଭାରତ ମାହାସାଗର କ୍ଷେତ୍ର)',
        'en_JE' => 'ଇଂରାଜୀ (ଜର୍ସି)',
        'en_JM' => 'ଇଂରାଜୀ (ଜାମାଇକା)',
        'en_KE' => 'ଇଂରାଜୀ (କେନିୟା)',
        'en_KI' => 'ଇଂରାଜୀ (କିରିବାଟି)',
        'en_KN' => 'ଇଂରାଜୀ (ସେଣ୍ଟ କିଟସ୍‌ ଏବଂ ନେଭିସ୍‌)',
        'en_KY' => 'ଇଂରାଜୀ (କେମ୍ୟାନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_LC' => 'ଇଂରାଜୀ (ସେଣ୍ଟ ଲୁସିଆ)',
        'en_LR' => 'ଇଂରାଜୀ (ଲାଇବେରିଆ)',
        'en_LS' => 'ଇଂରାଜୀ (ଲେସୋଥୋ)',
        'en_MG' => 'ଇଂରାଜୀ (ମାଡାଗାସ୍କର୍)',
        'en_MH' => 'ଇଂରାଜୀ (ମାର୍ଶାଲ୍ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_MO' => 'ଇଂରାଜୀ (ମାକାଉ ଏସଏଆର୍‌ ଚାଇନା)',
        'en_MP' => 'ଇଂରାଜୀ (ଉତ୍ତର ମାରିଆନା ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_MS' => 'ଇଂରାଜୀ (ମଣ୍ଟେସେରାଟ୍)',
        'en_MT' => 'ଇଂରାଜୀ (ମାଲ୍ଟା)',
        'en_MU' => 'ଇଂରାଜୀ (ମରିସସ)',
        'en_MV' => 'ଇଂରାଜୀ (ମାଲଦିଭସ୍‌)',
        'en_MW' => 'ଇଂରାଜୀ (ମାଲୱି)',
        'en_MY' => 'ଇଂରାଜୀ (ମାଲେସିଆ)',
        'en_NA' => 'ଇଂରାଜୀ (ନାମିବିଆ)',
        'en_NF' => 'ଇଂରାଜୀ (ନର୍ଫକ୍ ଦ୍ଵୀପ)',
        'en_NG' => 'ଇଂରାଜୀ (ନାଇଜେରିଆ)',
        'en_NL' => 'ଇଂରାଜୀ (ନେଦରଲ୍ୟାଣ୍ଡ)',
        'en_NR' => 'ଇଂରାଜୀ (ନାଉରୁ)',
        'en_NU' => 'ଇଂରାଜୀ (ନିଉ)',
        'en_NZ' => 'ଇଂରାଜୀ (ନ୍ୟୁଜିଲାଣ୍ଡ)',
        'en_PG' => 'ଇଂରାଜୀ (ପପୁଆ ନ୍ୟୁ ଗୁଏନିଆ)',
        'en_PH' => 'ଇଂରାଜୀ (ଫିଲିପାଇନସ୍)',
        'en_PK' => 'ଇଂରାଜୀ (ପାକିସ୍ତାନ)',
        'en_PN' => 'ଇଂରାଜୀ (ପିଟକାଇରିନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_PR' => 'ଇଂରାଜୀ (ପୁଏର୍ତ୍ତୋ ରିକୋ)',
        'en_PW' => 'ଇଂରାଜୀ (ପାଲାଉ)',
        'en_RW' => 'ଇଂରାଜୀ (ରାୱାଣ୍ଡା)',
        'en_SB' => 'ଇଂରାଜୀ (ସୋଲୋମନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_SC' => 'ଇଂରାଜୀ (ସେଚେଲସ୍)',
        'en_SD' => 'ଇଂରାଜୀ (ସୁଦାନ)',
        'en_SE' => 'ଇଂରାଜୀ (ସ୍ୱେଡେନ୍)',
        'en_SG' => 'ଇଂରାଜୀ (ସିଙ୍ଗାପୁର୍)',
        'en_SH' => 'ଇଂରାଜୀ (ସେଣ୍ଟ ହେଲେନା)',
        'en_SI' => 'ଇଂରାଜୀ (ସ୍ଲୋଭେନିଆ)',
        'en_SL' => 'ଇଂରାଜୀ (ସିଏରା ଲିଓନ)',
        'en_SS' => 'ଇଂରାଜୀ (ଦକ୍ଷିଣ ସୁଦାନ)',
        'en_SX' => 'ଇଂରାଜୀ (ସିଣ୍ଟ ମାର୍ଟୀନ୍‌)',
        'en_SZ' => 'ଇଂରାଜୀ (ଇସ୍ୱାତିନୀ)',
        'en_TC' => 'ଇଂରାଜୀ (ତୁର୍କସ୍‌ ଏବଂ କାଇକୋସ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_TK' => 'ଇଂରାଜୀ (ଟୋକେଲାଉ)',
        'en_TO' => 'ଇଂରାଜୀ (ଟୋଙ୍ଗା)',
        'en_TT' => 'ଇଂରାଜୀ (ତ୍ରିନିଦାଦ୍ ଏବଂ ଟୋବାଗୋ)',
        'en_TV' => 'ଇଂରାଜୀ (ତୁଭାଲୁ)',
        'en_TZ' => 'ଇଂରାଜୀ (ତାଞ୍ଜାନିଆ)',
        'en_UG' => 'ଇଂରାଜୀ (ଉଗାଣ୍ଡା)',
        'en_UM' => 'ଇଂରାଜୀ (ଯୁକ୍ତରାଷ୍ଟ୍ର ଆଉଟ୍‌ଲାଇଙ୍ଗ ଦ୍ଵୀପପୁଞ୍ଜ)',
        'en_US' => 'ଇଂରାଜୀ (ଯୁକ୍ତ ରାଷ୍ଟ୍ର)',
        'en_VC' => 'ଇଂରାଜୀ (ସେଣ୍ଟ ଭିନସେଣ୍ଟ ଏବଂ ଦି ଗ୍ରେନାଡିସ୍)',
        'en_VG' => 'ଇଂରାଜୀ (ବ୍ରିଟିଶ୍‌ ଭର୍ଜିନ୍ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'en_VI' => 'ଇଂରାଜୀ (ଯୁକ୍ତରାଷ୍ଟ୍ର ଭିର୍ଜିନ୍ ଦ୍ଵୀପପୁଞ୍ଜ)',
        'en_VU' => 'ଇଂରାଜୀ (ଭାନୁଆତୁ)',
        'en_WS' => 'ଇଂରାଜୀ (ସାମୋଆ)',
        'en_ZA' => 'ଇଂରାଜୀ (ଦକ୍ଷିଣ ଆଫ୍ରିକା)',
        'en_ZM' => 'ଇଂରାଜୀ (ଜାମ୍ବିଆ)',
        'en_ZW' => 'ଇଂରାଜୀ (ଜିମ୍ବାୱେ)',
        'eo' => 'ଏସ୍ପାରେଣ୍ଟୋ',
        'eo_001' => 'ଏସ୍ପାରେଣ୍ଟୋ (ବିଶ୍ୱ)',
        'es' => 'ସ୍ପେନିୟ',
        'es_419' => 'ସ୍ପେନିୟ (ଲାଟିନ୍‌ ଆମେରିକା)',
        'es_AR' => 'ସ୍ପେନିୟ (ଆର୍ଜେଣ୍ଟିନା)',
        'es_BO' => 'ସ୍ପେନିୟ (ବୋଲଭିଆ)',
        'es_BR' => 'ସ୍ପେନିୟ (ବ୍ରାଜିଲ୍)',
        'es_BZ' => 'ସ୍ପେନିୟ (ବେଲିଜ୍)',
        'es_CL' => 'ସ୍ପେନିୟ (ଚିଲ୍ଲୀ)',
        'es_CO' => 'ସ୍ପେନିୟ (କୋଲମ୍ବିଆ)',
        'es_CR' => 'ସ୍ପେନିୟ (କୋଷ୍ଟା ରିକା)',
        'es_CU' => 'ସ୍ପେନିୟ (କ୍ୱିବା)',
        'es_DO' => 'ସ୍ପେନିୟ (ଡୋମିନିକାନ୍‌ ସାଧାରଣତନ୍ତ୍ର)',
        'es_EC' => 'ସ୍ପେନିୟ (ଇକ୍ୱାଡୋର୍)',
        'es_ES' => 'ସ୍ପେନିୟ (ସ୍ପେନ୍)',
        'es_GQ' => 'ସ୍ପେନିୟ (ଇକ୍ବାଟେରିଆଲ୍ ଗୁଇନିଆ)',
        'es_GT' => 'ସ୍ପେନିୟ (ଗୁଏତମାଲା)',
        'es_HN' => 'ସ୍ପେନିୟ (ହୋଣ୍ଡୁରାସ୍‌)',
        'es_MX' => 'ସ୍ପେନିୟ (ମେକ୍ସିକୋ)',
        'es_NI' => 'ସ୍ପେନିୟ (ନିକାରାଗୁଆ)',
        'es_PA' => 'ସ୍ପେନିୟ (ପାନାମା)',
        'es_PE' => 'ସ୍ପେନିୟ (ପେରୁ)',
        'es_PH' => 'ସ୍ପେନିୟ (ଫିଲିପାଇନସ୍)',
        'es_PR' => 'ସ୍ପେନିୟ (ପୁଏର୍ତ୍ତୋ ରିକୋ)',
        'es_PY' => 'ସ୍ପେନିୟ (ପାରାଗୁଏ)',
        'es_SV' => 'ସ୍ପେନିୟ (ଏଲ୍ ସାଲଭାଡୋର୍)',
        'es_US' => 'ସ୍ପେନିୟ (ଯୁକ୍ତ ରାଷ୍ଟ୍ର)',
        'es_UY' => 'ସ୍ପେନିୟ (ଉରୁଗୁଏ)',
        'es_VE' => 'ସ୍ପେନିୟ (ଭେନେଜୁଏଲା)',
        'et' => 'ଏସ୍ତୋନିଆନ୍',
        'et_EE' => 'ଏସ୍ତୋନିଆନ୍ (ଏସ୍ତୋନିଆ)',
        'eu' => 'ବାସ୍କ୍ୱି',
        'eu_ES' => 'ବାସ୍କ୍ୱି (ସ୍ପେନ୍)',
        'fa' => 'ପର୍ସିଆନ୍',
        'fa_AF' => 'ପର୍ସିଆନ୍ (ଆଫଗାନିସ୍ତାନ୍)',
        'fa_IR' => 'ପର୍ସିଆନ୍ (ଇରାନ)',
        'ff' => 'ଫୁଲାହ',
        'ff_Adlm' => 'ଫୁଲାହ (ଆଡଲମ୍)',
        'ff_Adlm_BF' => 'ଫୁଲାହ (ଆଡଲମ୍, ବୁର୍କିନା ଫାସୋ)',
        'ff_Adlm_CM' => 'ଫୁଲାହ (ଆଡଲମ୍, କାମେରୁନ୍)',
        'ff_Adlm_GH' => 'ଫୁଲାହ (ଆଡଲମ୍, ଘାନା)',
        'ff_Adlm_GM' => 'ଫୁଲାହ (ଆଡଲମ୍, ଗାମ୍ବିଆ)',
        'ff_Adlm_GN' => 'ଫୁଲାହ (ଆଡଲମ୍, ଗୁଇନିଆ)',
        'ff_Adlm_GW' => 'ଫୁଲାହ (ଆଡଲମ୍, ଗୁଇନିଆ-ବିସାଉ)',
        'ff_Adlm_LR' => 'ଫୁଲାହ (ଆଡଲମ୍, ଲାଇବେରିଆ)',
        'ff_Adlm_MR' => 'ଫୁଲାହ (ଆଡଲମ୍, ମୌରିଟାନିଆ)',
        'ff_Adlm_NE' => 'ଫୁଲାହ (ଆଡଲମ୍, ନାଇଜର)',
        'ff_Adlm_NG' => 'ଫୁଲାହ (ଆଡଲମ୍, ନାଇଜେରିଆ)',
        'ff_Adlm_SL' => 'ଫୁଲାହ (ଆଡଲମ୍, ସିଏରା ଲିଓନ)',
        'ff_Adlm_SN' => 'ଫୁଲାହ (ଆଡଲମ୍, ସେନେଗାଲ୍)',
        'ff_CM' => 'ଫୁଲାହ (କାମେରୁନ୍)',
        'ff_GN' => 'ଫୁଲାହ (ଗୁଇନିଆ)',
        'ff_Latn' => 'ଫୁଲାହ (ଲାଟିନ୍)',
        'ff_Latn_BF' => 'ଫୁଲାହ (ଲାଟିନ୍, ବୁର୍କିନା ଫାସୋ)',
        'ff_Latn_CM' => 'ଫୁଲାହ (ଲାଟିନ୍, କାମେରୁନ୍)',
        'ff_Latn_GH' => 'ଫୁଲାହ (ଲାଟିନ୍, ଘାନା)',
        'ff_Latn_GM' => 'ଫୁଲାହ (ଲାଟିନ୍, ଗାମ୍ବିଆ)',
        'ff_Latn_GN' => 'ଫୁଲାହ (ଲାଟିନ୍, ଗୁଇନିଆ)',
        'ff_Latn_GW' => 'ଫୁଲାହ (ଲାଟିନ୍, ଗୁଇନିଆ-ବିସାଉ)',
        'ff_Latn_LR' => 'ଫୁଲାହ (ଲାଟିନ୍, ଲାଇବେରିଆ)',
        'ff_Latn_MR' => 'ଫୁଲାହ (ଲାଟିନ୍, ମୌରିଟାନିଆ)',
        'ff_Latn_NE' => 'ଫୁଲାହ (ଲାଟିନ୍, ନାଇଜର)',
        'ff_Latn_NG' => 'ଫୁଲାହ (ଲାଟିନ୍, ନାଇଜେରିଆ)',
        'ff_Latn_SL' => 'ଫୁଲାହ (ଲାଟିନ୍, ସିଏରା ଲିଓନ)',
        'ff_Latn_SN' => 'ଫୁଲାହ (ଲାଟିନ୍, ସେନେଗାଲ୍)',
        'ff_MR' => 'ଫୁଲାହ (ମୌରିଟାନିଆ)',
        'ff_SN' => 'ଫୁଲାହ (ସେନେଗାଲ୍)',
        'fi' => 'ଫିନ୍ନିସ୍',
        'fi_FI' => 'ଫିନ୍ନିସ୍ (ଫିନଲ୍ୟାଣ୍ଡ)',
        'fo' => 'ଫାରୋଏସେ',
        'fo_DK' => 'ଫାରୋଏସେ (ଡେନମାର୍କ)',
        'fo_FO' => 'ଫାରୋଏସେ (ଫାରୋଇ ଦ୍ୱୀପପୁଞ୍ଜ)',
        'fr' => 'ଫରାସୀ',
        'fr_BE' => 'ଫରାସୀ (ବେଲଜିୟମ୍)',
        'fr_BF' => 'ଫରାସୀ (ବୁର୍କିନା ଫାସୋ)',
        'fr_BI' => 'ଫରାସୀ (ବୁରୁଣ୍ଡି)',
        'fr_BJ' => 'ଫରାସୀ (ବେନିନ୍)',
        'fr_BL' => 'ଫରାସୀ (ସେଣ୍ଟ ବାର୍ଥେଲେମି)',
        'fr_CA' => 'ଫରାସୀ (କାନାଡା)',
        'fr_CD' => 'ଫରାସୀ (କଙ୍ଗୋ [ଡିଆରସି])',
        'fr_CF' => 'ଫରାସୀ (ମଧ୍ୟ ଆଫ୍ରିକୀୟ ସାଧାରଣତନ୍ତ୍ର)',
        'fr_CG' => 'ଫରାସୀ (କଙ୍ଗୋ-ବ୍ରାଜିଭିଲ୍ଲେ)',
        'fr_CH' => 'ଫରାସୀ (ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ)',
        'fr_CI' => 'ଫରାସୀ (କୋତ୍ ଡି ଭ୍ଵାର୍)',
        'fr_CM' => 'ଫରାସୀ (କାମେରୁନ୍)',
        'fr_DJ' => 'ଫରାସୀ (ଜିବୋଟି)',
        'fr_DZ' => 'ଫରାସୀ (ଆଲଜେରିଆ)',
        'fr_FR' => 'ଫରାସୀ (ଫ୍ରାନ୍ସ)',
        'fr_GA' => 'ଫରାସୀ (ଗାବୋନ୍)',
        'fr_GF' => 'ଫରାସୀ (ଫ୍ରେଞ୍ଚ ଗୁଇନା)',
        'fr_GN' => 'ଫରାସୀ (ଗୁଇନିଆ)',
        'fr_GP' => 'ଫରାସୀ (ଗୁଆଡେଲୋପ୍)',
        'fr_GQ' => 'ଫରାସୀ (ଇକ୍ବାଟେରିଆଲ୍ ଗୁଇନିଆ)',
        'fr_HT' => 'ଫରାସୀ (ହାଇତି)',
        'fr_KM' => 'ଫରାସୀ (କୋମୋରସ୍)',
        'fr_LU' => 'ଫରାସୀ (ଲକ୍ସେମବର୍ଗ)',
        'fr_MA' => 'ଫରାସୀ (ମୋରୋକ୍କୋ)',
        'fr_MC' => 'ଫରାସୀ (ମୋନାକୋ)',
        'fr_MF' => 'ଫରାସୀ (ସେଣ୍ଟ ମାର୍ଟିନ୍)',
        'fr_MG' => 'ଫରାସୀ (ମାଡାଗାସ୍କର୍)',
        'fr_ML' => 'ଫରାସୀ (ମାଲି)',
        'fr_MQ' => 'ଫରାସୀ (ମାର୍ଟିନିକ୍ୟୁ)',
        'fr_MR' => 'ଫରାସୀ (ମୌରିଟାନିଆ)',
        'fr_MU' => 'ଫରାସୀ (ମରିସସ)',
        'fr_NC' => 'ଫରାସୀ (ନୂତନ କାଲେଡୋନିଆ)',
        'fr_NE' => 'ଫରାସୀ (ନାଇଜର)',
        'fr_PF' => 'ଫରାସୀ (ଫ୍ରେଞ୍ଚ ପଲିନେସିଆ)',
        'fr_PM' => 'ଫରାସୀ (ସେଣ୍ଟ ପିଏରେ ଏବଂ ମିକ୍ୱେଲନ୍‌)',
        'fr_RE' => 'ଫରାସୀ (ରିୟୁନିଅନ୍)',
        'fr_RW' => 'ଫରାସୀ (ରାୱାଣ୍ଡା)',
        'fr_SC' => 'ଫରାସୀ (ସେଚେଲସ୍)',
        'fr_SN' => 'ଫରାସୀ (ସେନେଗାଲ୍)',
        'fr_SY' => 'ଫରାସୀ (ସିରିଆ)',
        'fr_TD' => 'ଫରାସୀ (ଚାଦ୍)',
        'fr_TG' => 'ଫରାସୀ (ଟୋଗୋ)',
        'fr_TN' => 'ଫରାସୀ (ଟ୍ୟୁନିସିଆ)',
        'fr_VU' => 'ଫରାସୀ (ଭାନୁଆତୁ)',
        'fr_WF' => 'ଫରାସୀ (ୱାଲିସ୍ ଏବଂ ଫୁତୁନା)',
        'fr_YT' => 'ଫରାସୀ (ମାୟୋଟେ)',
        'fy' => 'ପାଶ୍ଚାତ୍ୟ ଫ୍ରିସିଆନ୍',
        'fy_NL' => 'ପାଶ୍ଚାତ୍ୟ ଫ୍ରିସିଆନ୍ (ନେଦରଲ୍ୟାଣ୍ଡ)',
        'ga' => 'ଇରିସ୍',
        'ga_GB' => 'ଇରିସ୍ (ଯୁକ୍ତରାଜ୍ୟ)',
        'ga_IE' => 'ଇରିସ୍ (ଆୟରଲ୍ୟାଣ୍ଡ)',
        'gd' => 'ସ୍କଟିସ୍ ଗାଏଲିକ୍',
        'gd_GB' => 'ସ୍କଟିସ୍ ଗାଏଲିକ୍ (ଯୁକ୍ତରାଜ୍ୟ)',
        'gl' => 'ଗାଲସିଆନ୍',
        'gl_ES' => 'ଗାଲସିଆନ୍ (ସ୍ପେନ୍)',
        'gu' => 'ଗୁଜୁରାଟୀ',
        'gu_IN' => 'ଗୁଜୁରାଟୀ (ଭାରତ)',
        'gv' => 'ମାଁକ୍ସ',
        'gv_IM' => 'ମାଁକ୍ସ (ଆଇଲ୍‌ ଅଫ୍‌ ମ୍ୟାନ୍‌)',
        'ha' => 'ହୌସା',
        'ha_GH' => 'ହୌସା (ଘାନା)',
        'ha_NE' => 'ହୌସା (ନାଇଜର)',
        'ha_NG' => 'ହୌସା (ନାଇଜେରିଆ)',
        'he' => 'ହେବ୍ର୍ୟୁ',
        'he_IL' => 'ହେବ୍ର୍ୟୁ (ଇସ୍ରାଏଲ୍)',
        'hi' => 'ହିନ୍ଦୀ',
        'hi_IN' => 'ହିନ୍ଦୀ (ଭାରତ)',
        'hi_Latn' => 'ହିନ୍ଦୀ (ଲାଟିନ୍)',
        'hi_Latn_IN' => 'ହିନ୍ଦୀ (ଲାଟିନ୍, ଭାରତ)',
        'hr' => 'କ୍ରୋଆଟିଆନ୍',
        'hr_BA' => 'କ୍ରୋଆଟିଆନ୍ (ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'hr_HR' => 'କ୍ରୋଆଟିଆନ୍ (କ୍ରୋଏସିଆ)',
        'hu' => 'ହଙ୍ଗେରୀୟ',
        'hu_HU' => 'ହଙ୍ଗେରୀୟ (ହଙ୍ଗେରୀ)',
        'hy' => 'ଆର୍ମେନିଆନ୍',
        'hy_AM' => 'ଆର୍ମେନିଆନ୍ (ଆର୍ମେନିଆ)',
        'ia' => 'ଇର୍ଣ୍ଟଲିଙ୍ଗୁଆ',
        'ia_001' => 'ଇର୍ଣ୍ଟଲିଙ୍ଗୁଆ (ବିଶ୍ୱ)',
        'id' => 'ଇଣ୍ଡୋନେସୀୟ',
        'id_ID' => 'ଇଣ୍ଡୋନେସୀୟ (ଇଣ୍ଡୋନେସିଆ)',
        'ig' => 'ଇଗବୋ',
        'ig_NG' => 'ଇଗବୋ (ନାଇଜେରିଆ)',
        'ii' => 'ସିଚୁଆନ୍ ୟୀ',
        'ii_CN' => 'ସିଚୁଆନ୍ ୟୀ (ଚିନ୍)',
        'is' => 'ଆଇସଲାଣ୍ଡିକ୍',
        'is_IS' => 'ଆଇସଲାଣ୍ଡିକ୍ (ଆଇସଲ୍ୟାଣ୍ଡ)',
        'it' => 'ଇଟାଲୀୟ',
        'it_CH' => 'ଇଟାଲୀୟ (ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ)',
        'it_IT' => 'ଇଟାଲୀୟ (ଇଟାଲୀ)',
        'it_SM' => 'ଇଟାଲୀୟ (ସାନ୍ ମାରିନୋ)',
        'it_VA' => 'ଇଟାଲୀୟ (ଭାଟିକାନ୍ ସିଟି)',
        'ja' => 'ଜାପାନୀ',
        'ja_JP' => 'ଜାପାନୀ (ଜାପାନ)',
        'jv' => 'ଜାଭାନୀଜ୍',
        'jv_ID' => 'ଜାଭାନୀଜ୍ (ଇଣ୍ଡୋନେସିଆ)',
        'ka' => 'ଜର୍ଜିୟ',
        'ka_GE' => 'ଜର୍ଜିୟ (ଜର୍ଜିଆ)',
        'ki' => 'କୀକୁୟୁ',
        'ki_KE' => 'କୀକୁୟୁ (କେନିୟା)',
        'kk' => 'କାଜାକ୍',
        'kk_KZ' => 'କାଜାକ୍ (କାଜାକାସ୍ତାନ)',
        'kl' => 'କାଲାଲିସୁଟ୍',
        'kl_GL' => 'କାଲାଲିସୁଟ୍ (ଗ୍ରୀନଲ୍ୟାଣ୍ଡ)',
        'km' => 'ଖାମେର୍',
        'km_KH' => 'ଖାମେର୍ (କାମ୍ବୋଡିଆ)',
        'kn' => 'କନ୍ନଡ',
        'kn_IN' => 'କନ୍ନଡ (ଭାରତ)',
        'ko' => 'କୋରିଆନ୍',
        'ko_KP' => 'କୋରିଆନ୍ (ଉତ୍ତର କୋରିଆ)',
        'ko_KR' => 'କୋରିଆନ୍ (ଦକ୍ଷିଣ କୋରିଆ)',
        'ks' => 'କାଶ୍ମିରୀ',
        'ks_Arab' => 'କାଶ୍ମିରୀ (ଆରବିକ୍)',
        'ks_Arab_IN' => 'କାଶ୍ମିରୀ (ଆରବିକ୍, ଭାରତ)',
        'ks_Deva' => 'କାଶ୍ମିରୀ (ଦେବନଗରୀ)',
        'ks_Deva_IN' => 'କାଶ୍ମିରୀ (ଦେବନଗରୀ, ଭାରତ)',
        'ks_IN' => 'କାଶ୍ମିରୀ (ଭାରତ)',
        'ku' => 'କୁର୍ଦ୍ଦିଶ୍',
        'ku_TR' => 'କୁର୍ଦ୍ଦିଶ୍ (ତୁର୍କୀ)',
        'kw' => 'କୋର୍ନିସ୍',
        'kw_GB' => 'କୋର୍ନିସ୍ (ଯୁକ୍ତରାଜ୍ୟ)',
        'ky' => 'କୀରଗୀଜ୍',
        'ky_KG' => 'କୀରଗୀଜ୍ (କିର୍ଗିଜିସ୍ତାନ)',
        'lb' => 'ଲକ୍ସେମବର୍ଗିସ୍',
        'lb_LU' => 'ଲକ୍ସେମବର୍ଗିସ୍ (ଲକ୍ସେମବର୍ଗ)',
        'lg' => 'ଗନ୍ଦା',
        'lg_UG' => 'ଗନ୍ଦା (ଉଗାଣ୍ଡା)',
        'ln' => 'ଲିଙ୍ଗାଲା',
        'ln_AO' => 'ଲିଙ୍ଗାଲା (ଆଙ୍ଗୋଲା)',
        'ln_CD' => 'ଲିଙ୍ଗାଲା (କଙ୍ଗୋ [ଡିଆରସି])',
        'ln_CF' => 'ଲିଙ୍ଗାଲା (ମଧ୍ୟ ଆଫ୍ରିକୀୟ ସାଧାରଣତନ୍ତ୍ର)',
        'ln_CG' => 'ଲିଙ୍ଗାଲା (କଙ୍ଗୋ-ବ୍ରାଜିଭିଲ୍ଲେ)',
        'lo' => 'ଲାଓ',
        'lo_LA' => 'ଲାଓ (ଲାଓସ୍)',
        'lt' => 'ଲିଥୁଆନିଆନ୍',
        'lt_LT' => 'ଲିଥୁଆନିଆନ୍ (ଲିଥୁଆନିଆ)',
        'lu' => 'ଲ୍ୟୁବା-କାଟାଙ୍ଗା',
        'lu_CD' => 'ଲ୍ୟୁବା-କାଟାଙ୍ଗା (କଙ୍ଗୋ [ଡିଆରସି])',
        'lv' => 'ଲାଟଭିଆନ୍',
        'lv_LV' => 'ଲାଟଭିଆନ୍ (ଲାଟଭିଆ)',
        'mg' => 'ମାଲାଗାସୀ',
        'mg_MG' => 'ମାଲାଗାସୀ (ମାଡାଗାସ୍କର୍)',
        'mi' => 'ମାଓରୀ',
        'mi_NZ' => 'ମାଓରୀ (ନ୍ୟୁଜିଲାଣ୍ଡ)',
        'mk' => 'ମାସେଡୋନିଆନ୍',
        'mk_MK' => 'ମାସେଡୋନିଆନ୍ (ଉତ୍ତର ମାସେଡୋନିଆ)',
        'ml' => 'ମାଲାୟଲମ୍',
        'ml_IN' => 'ମାଲାୟଲମ୍ (ଭାରତ)',
        'mn' => 'ମଙ୍ଗୋଳିୟ',
        'mn_MN' => 'ମଙ୍ଗୋଳିୟ (ମଙ୍ଗୋଲିଆ)',
        'mr' => 'ମରାଠୀ',
        'mr_IN' => 'ମରାଠୀ (ଭାରତ)',
        'ms' => 'ମାଲୟ',
        'ms_BN' => 'ମାଲୟ (ବ୍ରୁନେଇ)',
        'ms_ID' => 'ମାଲୟ (ଇଣ୍ଡୋନେସିଆ)',
        'ms_MY' => 'ମାଲୟ (ମାଲେସିଆ)',
        'ms_SG' => 'ମାଲୟ (ସିଙ୍ଗାପୁର୍)',
        'mt' => 'ମାଲଟୀଜ୍',
        'mt_MT' => 'ମାଲଟୀଜ୍ (ମାଲ୍ଟା)',
        'my' => 'ବର୍ମୀଜ୍',
        'my_MM' => 'ବର୍ମୀଜ୍ (ମିଆଁମାର)',
        'nb' => 'ନରୱେଜିଆନ୍ ବୋକମଲ୍',
        'nb_NO' => 'ନରୱେଜିଆନ୍ ବୋକମଲ୍ (ନରୱେ)',
        'nb_SJ' => 'ନରୱେଜିଆନ୍ ବୋକମଲ୍ (ସାଲବାର୍ଡ ଏବଂ ଜାନ୍‌ ମାୟେନ୍‌)',
        'nd' => 'ଉତ୍ତର ନେଡବେଲେ',
        'nd_ZW' => 'ଉତ୍ତର ନେଡବେଲେ (ଜିମ୍ବାୱେ)',
        'ne' => 'ନେପାଳୀ',
        'ne_IN' => 'ନେପାଳୀ (ଭାରତ)',
        'ne_NP' => 'ନେପାଳୀ (ନେପାଳ)',
        'nl' => 'ଡଚ୍',
        'nl_AW' => 'ଡଚ୍ (ଆରୁବା)',
        'nl_BE' => 'ଡଚ୍ (ବେଲଜିୟମ୍)',
        'nl_BQ' => 'ଡଚ୍ (କାରବିୟନ୍‌ ନେଦରଲ୍ୟାଣ୍ଡ)',
        'nl_CW' => 'ଡଚ୍ (କୁରାକାଓ)',
        'nl_NL' => 'ଡଚ୍ (ନେଦରଲ୍ୟାଣ୍ଡ)',
        'nl_SR' => 'ଡଚ୍ (ସୁରିନାମ)',
        'nl_SX' => 'ଡଚ୍ (ସିଣ୍ଟ ମାର୍ଟୀନ୍‌)',
        'nn' => 'ନରୱେଜିଆନ୍ ନିୟୋର୍ସ୍କ',
        'nn_NO' => 'ନରୱେଜିଆନ୍ ନିୟୋର୍ସ୍କ (ନରୱେ)',
        'no' => 'ନରୱେଜିଆନ୍',
        'no_NO' => 'ନରୱେଜିଆନ୍ (ନରୱେ)',
        'om' => 'ଓରୋମୋ',
        'om_ET' => 'ଓରୋମୋ (ଇଥିଓପିଆ)',
        'om_KE' => 'ଓରୋମୋ (କେନିୟା)',
        'or' => 'ଓଡ଼ିଆ',
        'or_IN' => 'ଓଡ଼ିଆ (ଭାରତ)',
        'os' => 'ଓସେଟିକ୍',
        'os_GE' => 'ଓସେଟିକ୍ (ଜର୍ଜିଆ)',
        'os_RU' => 'ଓସେଟିକ୍ (ରୁଷିଆ)',
        'pa' => 'ପଞ୍ଜାବୀ',
        'pa_Arab' => 'ପଞ୍ଜାବୀ (ଆରବିକ୍)',
        'pa_Arab_PK' => 'ପଞ୍ଜାବୀ (ଆରବିକ୍, ପାକିସ୍ତାନ)',
        'pa_Guru' => 'ପଞ୍ଜାବୀ (ଗୁରମୁଖୀ)',
        'pa_Guru_IN' => 'ପଞ୍ଜାବୀ (ଗୁରମୁଖୀ, ଭାରତ)',
        'pa_IN' => 'ପଞ୍ଜାବୀ (ଭାରତ)',
        'pa_PK' => 'ପଞ୍ଜାବୀ (ପାକିସ୍ତାନ)',
        'pl' => 'ପୋଲିଶ୍',
        'pl_PL' => 'ପୋଲିଶ୍ (ପୋଲାଣ୍ଡ)',
        'ps' => 'ପାସ୍ତୋ',
        'ps_AF' => 'ପାସ୍ତୋ (ଆଫଗାନିସ୍ତାନ୍)',
        'ps_PK' => 'ପାସ୍ତୋ (ପାକିସ୍ତାନ)',
        'pt' => 'ପର୍ତ୍ତୁଗୀଜ୍‌',
        'pt_AO' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ଆଙ୍ଗୋଲା)',
        'pt_BR' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ବ୍ରାଜିଲ୍)',
        'pt_CH' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ)',
        'pt_CV' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (କେପ୍ ଭର୍ଦେ)',
        'pt_GQ' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ଇକ୍ବାଟେରିଆଲ୍ ଗୁଇନିଆ)',
        'pt_GW' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ଗୁଇନିଆ-ବିସାଉ)',
        'pt_LU' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ଲକ୍ସେମବର୍ଗ)',
        'pt_MO' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ମାକାଉ ଏସଏଆର୍‌ ଚାଇନା)',
        'pt_MZ' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ମୋଜାମ୍ବିକ୍‌)',
        'pt_PT' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ପର୍ତ୍ତୁଗାଲ୍)',
        'pt_ST' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ସାଓ ଟୋମେ ଏବଂ ପ୍ରିନସିପି)',
        'pt_TL' => 'ପର୍ତ୍ତୁଗୀଜ୍‌ (ତିମୋର୍-ଲେଷ୍ଟେ)',
        'qu' => 'କ୍ୱେଚୁଆ',
        'qu_BO' => 'କ୍ୱେଚୁଆ (ବୋଲଭିଆ)',
        'qu_EC' => 'କ୍ୱେଚୁଆ (ଇକ୍ୱାଡୋର୍)',
        'qu_PE' => 'କ୍ୱେଚୁଆ (ପେରୁ)',
        'rm' => 'ରୋମାନଶ୍‌',
        'rm_CH' => 'ରୋମାନଶ୍‌ (ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ)',
        'rn' => 'ରୁଣ୍ଡି',
        'rn_BI' => 'ରୁଣ୍ଡି (ବୁରୁଣ୍ଡି)',
        'ro' => 'ରୋମାନିଆନ୍',
        'ro_MD' => 'ରୋମାନିଆନ୍ (ମୋଲଡୋଭା)',
        'ro_RO' => 'ରୋମାନିଆନ୍ (ରୋମାନିଆ)',
        'ru' => 'ରୁଷିୟ',
        'ru_BY' => 'ରୁଷିୟ (ବେଲାରୁଷ୍)',
        'ru_KG' => 'ରୁଷିୟ (କିର୍ଗିଜିସ୍ତାନ)',
        'ru_KZ' => 'ରୁଷିୟ (କାଜାକାସ୍ତାନ)',
        'ru_MD' => 'ରୁଷିୟ (ମୋଲଡୋଭା)',
        'ru_RU' => 'ରୁଷିୟ (ରୁଷିଆ)',
        'ru_UA' => 'ରୁଷିୟ (ୟୁକ୍ରେନ୍)',
        'rw' => 'କିନ୍ୟାରୱାଣ୍ଡା',
        'rw_RW' => 'କିନ୍ୟାରୱାଣ୍ଡା (ରାୱାଣ୍ଡା)',
        'sa' => 'ସଂସ୍କୃତ',
        'sa_IN' => 'ସଂସ୍କୃତ (ଭାରତ)',
        'sc' => 'ସର୍ଦିନିଆନ୍',
        'sc_IT' => 'ସର୍ଦିନିଆନ୍ (ଇଟାଲୀ)',
        'sd' => 'ସିନ୍ଧୀ',
        'sd_Arab' => 'ସିନ୍ଧୀ (ଆରବିକ୍)',
        'sd_Arab_PK' => 'ସିନ୍ଧୀ (ଆରବିକ୍, ପାକିସ୍ତାନ)',
        'sd_Deva' => 'ସିନ୍ଧୀ (ଦେବନଗରୀ)',
        'sd_Deva_IN' => 'ସିନ୍ଧୀ (ଦେବନଗରୀ, ଭାରତ)',
        'sd_IN' => 'ସିନ୍ଧୀ (ଭାରତ)',
        'sd_PK' => 'ସିନ୍ଧୀ (ପାକିସ୍ତାନ)',
        'se' => 'ଉତ୍ତର ସାମି',
        'se_FI' => 'ଉତ୍ତର ସାମି (ଫିନଲ୍ୟାଣ୍ଡ)',
        'se_NO' => 'ଉତ୍ତର ସାମି (ନରୱେ)',
        'se_SE' => 'ଉତ୍ତର ସାମି (ସ୍ୱେଡେନ୍)',
        'sg' => 'ସାଙ୍ଗୋ',
        'sg_CF' => 'ସାଙ୍ଗୋ (ମଧ୍ୟ ଆଫ୍ରିକୀୟ ସାଧାରଣତନ୍ତ୍ର)',
        'sh' => 'ସର୍ବୋ-କ୍ରୋଆଟିଆନ୍',
        'sh_BA' => 'ସର୍ବୋ-କ୍ରୋଆଟିଆନ୍ (ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'si' => 'ସିଂହଳ',
        'si_LK' => 'ସିଂହଳ (ଶ୍ରୀଲଙ୍କା)',
        'sk' => 'ସ୍ଲୋଭାକ୍',
        'sk_SK' => 'ସ୍ଲୋଭାକ୍ (ସ୍ଲୋଭାକିଆ)',
        'sl' => 'ସ୍ଲୋଭେନିଆନ୍',
        'sl_SI' => 'ସ୍ଲୋଭେନିଆନ୍ (ସ୍ଲୋଭେନିଆ)',
        'sn' => 'ଶୋନା',
        'sn_ZW' => 'ଶୋନା (ଜିମ୍ବାୱେ)',
        'so' => 'ସୋମାଲିଆ',
        'so_DJ' => 'ସୋମାଲିଆ (ଜିବୋଟି)',
        'so_ET' => 'ସୋମାଲିଆ (ଇଥିଓପିଆ)',
        'so_KE' => 'ସୋମାଲିଆ (କେନିୟା)',
        'so_SO' => 'ସୋମାଲିଆ (ସୋମାଲିଆ)',
        'sq' => 'ଆଲବାନିଆନ୍',
        'sq_AL' => 'ଆଲବାନିଆନ୍ (ଆଲବାନିଆ)',
        'sq_MK' => 'ଆଲବାନିଆନ୍ (ଉତ୍ତର ମାସେଡୋନିଆ)',
        'sr' => 'ସର୍ବିୟ',
        'sr_BA' => 'ସର୍ବିୟ (ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'sr_Cyrl' => 'ସର୍ବିୟ (ସିରିଲିକ୍)',
        'sr_Cyrl_BA' => 'ସର୍ବିୟ (ସିରିଲିକ୍, ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'sr_Cyrl_ME' => 'ସର୍ବିୟ (ସିରିଲିକ୍, ମଣ୍ଟେନିଗ୍ରୋ)',
        'sr_Cyrl_RS' => 'ସର୍ବିୟ (ସିରିଲିକ୍, ସର୍ବିଆ)',
        'sr_Latn' => 'ସର୍ବିୟ (ଲାଟିନ୍)',
        'sr_Latn_BA' => 'ସର୍ବିୟ (ଲାଟିନ୍, ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା)',
        'sr_Latn_ME' => 'ସର୍ବିୟ (ଲାଟିନ୍, ମଣ୍ଟେନିଗ୍ରୋ)',
        'sr_Latn_RS' => 'ସର୍ବିୟ (ଲାଟିନ୍, ସର୍ବିଆ)',
        'sr_ME' => 'ସର୍ବିୟ (ମଣ୍ଟେନିଗ୍ରୋ)',
        'sr_RS' => 'ସର୍ବିୟ (ସର୍ବିଆ)',
        'su' => 'ସୁଦାନୀଜ୍',
        'su_ID' => 'ସୁଦାନୀଜ୍ (ଇଣ୍ଡୋନେସିଆ)',
        'su_Latn' => 'ସୁଦାନୀଜ୍ (ଲାଟିନ୍)',
        'su_Latn_ID' => 'ସୁଦାନୀଜ୍ (ଲାଟିନ୍, ଇଣ୍ଡୋନେସିଆ)',
        'sv' => 'ସ୍ୱେଡିସ୍',
        'sv_AX' => 'ସ୍ୱେଡିସ୍ (ଅଲାଣ୍ଡ ଦ୍ଵୀପପୁଞ୍ଜ)',
        'sv_FI' => 'ସ୍ୱେଡିସ୍ (ଫିନଲ୍ୟାଣ୍ଡ)',
        'sv_SE' => 'ସ୍ୱେଡିସ୍ (ସ୍ୱେଡେନ୍)',
        'sw' => 'ସ୍ୱାହିଲ୍',
        'sw_CD' => 'ସ୍ୱାହିଲ୍ (କଙ୍ଗୋ [ଡିଆରସି])',
        'sw_KE' => 'ସ୍ୱାହିଲ୍ (କେନିୟା)',
        'sw_TZ' => 'ସ୍ୱାହିଲ୍ (ତାଞ୍ଜାନିଆ)',
        'sw_UG' => 'ସ୍ୱାହିଲ୍ (ଉଗାଣ୍ଡା)',
        'ta' => 'ତାମିଲ୍',
        'ta_IN' => 'ତାମିଲ୍ (ଭାରତ)',
        'ta_LK' => 'ତାମିଲ୍ (ଶ୍ରୀଲଙ୍କା)',
        'ta_MY' => 'ତାମିଲ୍ (ମାଲେସିଆ)',
        'ta_SG' => 'ତାମିଲ୍ (ସିଙ୍ଗାପୁର୍)',
        'te' => 'ତେଲୁଗୁ',
        'te_IN' => 'ତେଲୁଗୁ (ଭାରତ)',
        'tg' => 'ତାଜିକ୍',
        'tg_TJ' => 'ତାଜିକ୍ (ତାଜିକିସ୍ଥାନ୍)',
        'th' => 'ଥାଇ',
        'th_TH' => 'ଥାଇ (ଥାଇଲ୍ୟାଣ୍ଡ)',
        'ti' => 'ଟ୍ରିଗିନିଆ',
        'ti_ER' => 'ଟ୍ରିଗିନିଆ (ଇରିଟ୍ରିୟା)',
        'ti_ET' => 'ଟ୍ରିଗିନିଆ (ଇଥିଓପିଆ)',
        'tk' => 'ତୁର୍କମେନ୍',
        'tk_TM' => 'ତୁର୍କମେନ୍ (ତୁର୍କମେନିସ୍ତାନ)',
        'tl' => 'ଟାଗାଲଗ୍',
        'tl_PH' => 'ଟାଗାଲଗ୍ (ଫିଲିପାଇନସ୍)',
        'to' => 'ଟୋଙ୍ଗା',
        'to_TO' => 'ଟୋଙ୍ଗା (ଟୋଙ୍ଗା)',
        'tr' => 'ତୁର୍କିସ୍',
        'tr_CY' => 'ତୁର୍କିସ୍ (ସାଇପ୍ରସ୍)',
        'tr_TR' => 'ତୁର୍କିସ୍ (ତୁର୍କୀ)',
        'tt' => 'ତାତାର୍',
        'tt_RU' => 'ତାତାର୍ (ରୁଷିଆ)',
        'ug' => 'ୟୁଘୁର୍',
        'ug_CN' => 'ୟୁଘୁର୍ (ଚିନ୍)',
        'uk' => 'ୟୁକ୍ରାନିଆନ୍',
        'uk_UA' => 'ୟୁକ୍ରାନିଆନ୍ (ୟୁକ୍ରେନ୍)',
        'ur' => 'ଉର୍ଦ୍ଦୁ',
        'ur_IN' => 'ଉର୍ଦ୍ଦୁ (ଭାରତ)',
        'ur_PK' => 'ଉର୍ଦ୍ଦୁ (ପାକିସ୍ତାନ)',
        'uz' => 'ଉଜବେକ୍',
        'uz_AF' => 'ଉଜବେକ୍ (ଆଫଗାନିସ୍ତାନ୍)',
        'uz_Arab' => 'ଉଜବେକ୍ (ଆରବିକ୍)',
        'uz_Arab_AF' => 'ଉଜବେକ୍ (ଆରବିକ୍, ଆଫଗାନିସ୍ତାନ୍)',
        'uz_Cyrl' => 'ଉଜବେକ୍ (ସିରିଲିକ୍)',
        'uz_Cyrl_UZ' => 'ଉଜବେକ୍ (ସିରିଲିକ୍, ଉଜବେକିସ୍ତାନ)',
        'uz_Latn' => 'ଉଜବେକ୍ (ଲାଟିନ୍)',
        'uz_Latn_UZ' => 'ଉଜବେକ୍ (ଲାଟିନ୍, ଉଜବେକିସ୍ତାନ)',
        'uz_UZ' => 'ଉଜବେକ୍ (ଉଜବେକିସ୍ତାନ)',
        'vi' => 'ଭିଏତନାମିଜ୍',
        'vi_VN' => 'ଭିଏତନାମିଜ୍ (ଭିଏତନାମ୍)',
        'wo' => 'ୱୋଲଫ୍',
        'wo_SN' => 'ୱୋଲଫ୍ (ସେନେଗାଲ୍)',
        'xh' => 'ଖୋସା',
        'xh_ZA' => 'ଖୋସା (ଦକ୍ଷିଣ ଆଫ୍ରିକା)',
        'yi' => 'ୟିଡିସ୍',
        'yi_001' => 'ୟିଡିସ୍ (ବିଶ୍ୱ)',
        'yo' => 'ୟୋରୁବା',
        'yo_BJ' => 'ୟୋରୁବା (ବେନିନ୍)',
        'yo_NG' => 'ୟୋରୁବା (ନାଇଜେରିଆ)',
        'zh' => 'ଚାଇନିଜ୍‌',
        'zh_CN' => 'ଚାଇନିଜ୍‌ (ଚିନ୍)',
        'zh_HK' => 'ଚାଇନିଜ୍‌ (ହଂ କଂ ଏସଏଆର୍‌ ଚାଇନା)',
        'zh_Hans' => 'ଚାଇନିଜ୍‌ (ସରଳୀକୃତ)',
        'zh_Hans_CN' => 'ଚାଇନିଜ୍‌ (ସରଳୀକୃତ, ଚିନ୍)',
        'zh_Hans_HK' => 'ଚାଇନିଜ୍‌ (ସରଳୀକୃତ, ହଂ କଂ ଏସଏଆର୍‌ ଚାଇନା)',
        'zh_Hans_MO' => 'ଚାଇନିଜ୍‌ (ସରଳୀକୃତ, ମାକାଉ ଏସଏଆର୍‌ ଚାଇନା)',
        'zh_Hans_SG' => 'ଚାଇନିଜ୍‌ (ସରଳୀକୃତ, ସିଙ୍ଗାପୁର୍)',
        'zh_Hant' => 'ଚାଇନିଜ୍‌ (ପାରମ୍ପରିକ)',
        'zh_Hant_HK' => 'ଚାଇନିଜ୍‌ (ପାରମ୍ପରିକ, ହଂ କଂ ଏସଏଆର୍‌ ଚାଇନା)',
        'zh_Hant_MO' => 'ଚାଇନିଜ୍‌ (ପାରମ୍ପରିକ, ମାକାଉ ଏସଏଆର୍‌ ଚାଇନା)',
        'zh_Hant_TW' => 'ଚାଇନିଜ୍‌ (ପାରମ୍ପରିକ, ତାଇୱାନ)',
        'zh_MO' => 'ଚାଇନିଜ୍‌ (ମାକାଉ ଏସଏଆର୍‌ ଚାଇନା)',
        'zh_SG' => 'ଚାଇନିଜ୍‌ (ସିଙ୍ଗାପୁର୍)',
        'zh_TW' => 'ଚାଇନିଜ୍‌ (ତାଇୱାନ)',
        'zu' => 'ଜୁଲୁ',
        'zu_ZA' => 'ଜୁଲୁ (ଦକ୍ଷିଣ ଆଫ୍ରିକା)',
    ],
];
